@@ -1,5 +1,5 @@
 package Net::Kubernetes;
-$Net::Kubernetes::VERSION = '0.02';
+$Net::Kubernetes::VERSION = '0.03';
 use Moose;
 use Data::Dumper;
 require Net::Kubernetes::Namespace;
@@ -19,7 +19,7 @@ Net::Kubernetes
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 SYNOPSIS
 
@@ -55,6 +55,43 @@ with 'Net::Kubernetes::Role::ResourceCreator';
 =head1 Methods
 
 By convention, methods will throw exceptions if kubernetes api server returns a non-successful status code.
+Unless otherwise noted, assume this behavoir through out.
+
+=over 1
+
+=item new - Create a new $kube object
+
+All parameters are optional and have some basic default values (where appropriate).
+
+=over 1
+
+=item url ['http://localhost:8080']
+
+The base url for the kubernetes. This should include the protocal (http or https) but not "/api/v1beta3" (see base_path).
+
+=item base_path ['/api/v1beta3']
+
+The entry point for api calls, this may be used to set the api version with which to interact.
+
+=item username
+
+Username to use with basic authentication. If either username or password are not provided, basic authentication will not
+be used.
+
+=item password
+
+Password to use with basic authentication. If either username or password are not provided, basic authentication will not
+be used.
+
+=item token
+
+An authentication token to be used to access the apiserver.  This may be provided as a plain string, a path to a file
+from which to read the token (like /var/run/secrets/kubernetes.io/serviceaccount/token from within a pod), or a reference
+to a file handle (from which to read the token).
+
+=back
+
+=back
 
 =head2 List resources
 
@@ -134,7 +171,9 @@ These methods can be called directly on a resource object.
 
 =item $resource->delete
 
-=item $resource->refresh
+=item $resource->refresh (update object from api server)
+
+=item $resource->update (send local changes to api server)
 
 This method is only available for resources which have a status (currently everything
 other than secretes).
