@@ -1,5 +1,5 @@
 package Net::Kubernetes::Resource;
-$Net::Kubernetes::Resource::VERSION = '0.02';
+$Net::Kubernetes::Resource::VERSION = '0.03';
 use Moose;
 
 =head1 NAME
@@ -8,7 +8,7 @@ Net::Kubernetes::Resource
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =cut
 
@@ -42,5 +42,16 @@ sub delete {
 	return 0;
 }
 
+sub update {
+	my($self) = @_;
+	my($res) = $self->ua->request($self->create_request(PUT => $self->url.'/'.$self->base_path, undef, $self->json->encode({spec=>$self->spec, apiVersion=>$self->api_version, kind=>$self->kind, metadata=>$self->metadata})));
+	if ($res->is_success) {
+		return 1;
+	}
+	use Data::Dumper;
+	print Dumper($res)."\n";
+	return 0;
+}
+
 
 return 42;
