@@ -1,5 +1,5 @@
 package Net::Kubernetes::Role::APIAccess;
-$Net::Kubernetes::Role::APIAccess::VERSION = '0.02';
+$Net::Kubernetes::Role::APIAccess::VERSION = '0.03';
 use Moose::Role;
 require LWP::UserAgent;
 require HTTP::Request;
@@ -13,7 +13,7 @@ Net::Kubernetes::Role::APIAccess
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =cut
 
@@ -51,6 +51,12 @@ has ua => (
 	builder  => '_build_lwp_agent',
 );
 
+has token => (
+	is       => 'ro',
+	isa      => 'Str',
+	required => 0
+);
+
 has 'json' => (
     is       => 'ro',
     isa      => 'JSON',
@@ -59,12 +65,25 @@ has 'json' => (
     builder  => '_build_json',
 );
 
+around BUILDARGS => sub {
+	my $orig = shift;
+	my $class = shift;
+	my(%input) = @_;
+	if(ref($input{token}) && $input{token}->can('getlines')){
+		$input{token} = join('', $input{token}->getlines);
+	}elsif (exists $input{token} && -f $input{token}) {
+		open(my $fh, '<', $input{token});
+		$input{token} = do{ local $/; <$fh>};
+		close($fh);
+	}
+	return $class->$orig(%input);
+};
+
 sub path {
 	my($self) = @_;
 	return $self->url.'/'.$self->base_path;
 }
 
-
 sub _build_lwp_agent {
 	my $self = shift;
 	my $ua = LWP::UserAgent->new(agent=>'net-kubernetes-perl/0.01');
@@ -82,6 +101,9 @@ sub create_request {
 	if ($self->username && $self->password) {
 		$req->header(Authorization=>"Basic ".encode_base64($self->username.':'.$self->password));
 	}
+	elsif($self->token){
+		$req->header(Authorization=>"Bearer ".$self->token);
+	}
 	return $req;
 }
 
