@@ -1,5 +1,5 @@
 package Net::Kubernetes::Role::ResourceCreator;
-$Net::Kubernetes::Role::ResourceCreator::VERSION = '0.02';
+$Net::Kubernetes::Role::ResourceCreator::VERSION = '0.03';
 use Moose::Role;
 use MooseX::Aliases;
 require YAML;
@@ -17,10 +17,12 @@ Net::Kubernetes::Role::ResoruceCreator
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =cut
 
+with 'Net::Kubernetes::Role::ResourceFactory';
+
 requires 'ua';
 requires 'create_request';
 requires 'json';
@@ -48,7 +50,7 @@ sub create {
 	my $req = $self->create_request(POST=>$self->path.'/'.lc($object->{kind}).'s', undef, $self->json->encode($object));
 	my $res = $self->ua->request($req);
 	if ($res->is_success) {
-		return "Net::Kubernetes::Resource::$object->{kind}"->new($self->json->decode($res->content));
+		return $self->create_resource_object($self->json->decode($res->content));
 	}else{
 		Net::Kubernetes::Exception->throw(code=>$res->code, message=>"Error creating resource:\n".$res->message);
 	}
